@@ -66,7 +66,7 @@ _OPTIONS = [
 
     Opt('release_tag_re',
         textwrap.dedent('''\
-        ((?:[\d.ab]|rc)+)  # digits, a, b, and rc cover regular and
+        ((?:v?[\d.ab]|rc)+)  # digits, a, b, and rc cover regular and
                            # pre-releases
         '''),
         textwrap.dedent("""\
@@ -77,7 +77,7 @@ _OPTIONS = [
 
     Opt('pre_release_tag_re',
         textwrap.dedent('''\
-        (?P<pre_release>\.\d+(?:[ab]|rc)+\d*)$
+        (?P<pre_release>\.v?\d+(?:[ab]|rc)+\d*)$
         '''),
         textwrap.dedent("""\
         The regex pattern used to check if a valid release version tag
@@ -167,6 +167,13 @@ _OPTIONS = [
         the ``ignore-notes`` parameter to the ``release-notes`` sphinx
         directive.
         """)),
+
+    Opt('unreleased_version_title', '',
+        textwrap.dedent("""\
+        The title to use for any notes that do not appear in a
+        released version. If this option is unset, the development
+        version number is used (for example, ``3.0.0-3``).
+        """)),
 ]
 
 
